#
# spec file for package python-py3status
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-py3status
Version:        3.57
Release:        1.1
Summary:        Python extensible i3status wrapper
License:        BSD-3-Clause
URL:            https://github.com/ultrabug/py3status
Source:         https://github.com/ultrabug/py3status/archive/3.57.tar.gz#/py3status-3.57.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyudev >= 0.21.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     i3status
Recommends:     python-dbus-python
Recommends:     python-pyudev >= 0.21.0
Provides:       py3status = %{version}
Obsoletes:      py3status < %{version}
BuildArch:      noarch
%python_subpackages

%description
py3status is an extensible i3status wrapper written in python.

Using py3status, you can take control of your i3bar easily by:

- using one of the availables modules shipped with py3status
- writing your own modules and have their output displayed on your bar
- handling click events on your i3bar and play with them in no time
- seeing your clock tick every second whatever your i3status interval

py3status has a standalone mode allowing to bypass i3status when you need
a py3status-modules-only i3bar.

%prep
%setup -q -n py3status-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/py3status
%python_clone -a %{buildroot}%{_bindir}/py3-cmd
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
%pytest tests/

%post
%python_install_alternative py3status
%python_install_alternative py3-cmd

%postun
%python_uninstall_alternative py3status
%python_uninstall_alternative py3-cmd

%files %{python_files}
%license LICENSE
%doc CHANGELOG README.md
%python_alternative %{_bindir}/py3status
%python_alternative %{_bindir}/py3-cmd
%{python_sitelib}/py3status
%{python_sitelib}/py3status-%{version}*-info

%changelog
* Fri May 31 2024 Dawid Adam <nyslay@gmail.com>
- update to 3.57:
  * docs: explain how to serve mkdocs locally
  * add CodeQL workflow for GitHub code scanning
  * fmt: fix newer black
  * backlight module: add brightnessctl support
  * conky module: workaround upstream issues/1479
  * volume_status module: fix for default source with pamixer
* Fri May 31 2024 Dawid Adam <nyslay@gmail.com>
- update to 3.56:
  * remove audio modules in favor of playerctl
  * new module dexcom:  display glucose readings from your Dexcom CGM system
  * arch_updates module: hourly cache_timeout, add a note about alpm-hooks
  * volume_status module: pamixer fix command if device is 0
  * volume_status module: pamixer: Use default device if none specified
* Fri May 31 2024 Dawid Adam <nyslay@gmail.com>
- uprate to 3.55:
  * pkg: add dbus tag to pull dependencies 'pip install py3status[dbus]'
  * pkg: drop eol python 3.7 support, add python 3.12
  * pkg: pull setuptools for 3.12
  * docs(build): move away from readthedocs and switch to automatic github pages
  * docs(config): add favicon and rename the site
  * readme: drop readthedocs build status
  * docs: fix broken 404 urls
  * arch_updates module: update auracle from sync to outdated
  * bluetooth module: reinitialize dbus to fix after sleep behavior
  * lm_sensors module: fix invalid json if specified more than one chip
  * nvidia_smi module: fix --list-properties
  * vpn_status module: add formatters for displaying IP addresses of VPNs
* Fri May 31 2024 Dawid Adam <nyslay@gmail.com>
- update to 3.54:
  * arch_updates module: handle yay return code better when there are no updates
  * arch_updates module: make it more responsive to system updates
  * battery_level module: fix code style
* Fri May 31 2024 Dawid Adam <nyslay@gmail.com>
- update to 3.53:
  * argparser: remove deprecated interval option
  * new module playerctl: control players supported by playerctl
* Tue Aug  1 2023 nyslay@gmail.com
- update to 3.52:
  * IMPORTANT: the project has moved from setuptools to pyproject.toml and hatch
  * IMPORTANT: gevent support is now deprecated and removed
  * core: drop gevent support
* Fri Jun 30 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Fri Jun 30 2023 Dawid Adam <nyslay@gmail.com>
- Update to 3.51:
  * NEW: thanks to Andreas Grapentin, py3status can now run in lots of other containers (tmux, term, dzen2, lemonbar...)
  * IMPORTANT: modules are moving away from the obsolete pydbus library
  * core: implement handling of output_format in py3status for i3bar, dzen2, xmobar, lemonbar, tmux, term, none (#2104), by Andreas Grapentin
  * core: autodetect output_format (#2202), by lasers
  * fix(module): report module post_config_hook errors thx to @lasers (#2208)
  * docs(user): add a section to specify that modules dependencies are up to the users
  * docs(mkdocs): drop mkdocs-simple-hooks closes #2195
  * docs: fix two DeprecationWarning (#2191), by lasers
  * docs(audiosink): fix screenshots (#2194), by lasers
  * docs(autodoc): remove dead code thx to @lasers, closes #2183 (#2193)
  * arch_updates module: add support for pikaur (#2182), by vim
  * arch_updates module: remove cower support (gone) (#2190), by lasers
  * backlight module: drop pydbus, switch to dbus-python
  * bluetooth module: report battery percentage if available (#2185), by Alex Tsitsimpis
  * clock module: added timezone information to times implicitly using local system timezone (#2197), by Andreas Grapentin
  * clock module: minor patch to get the local timezone. (#2189), by Josh Sixsmith
  * diskdata module: fix variable init type
  * diskdata module: make module work on FreeBSD (#2200), by Björn Busse
  * mpd_status module: fix UnboundLocalError (#2199), by Björn Busse
  * ns_checker module: replace query() with resolve() (#2207), by Björn Busse
  * systemd module: drop pydbus, switch to dbus-python
  * vpn_status module: drop pydbus, switch to dbus-python
* Wed Apr 19 2023 Dawid Adam <nyslay@gmail.com>
- Update to 3.50:
  * update alpine install doc (#2176), by raspbeguy
  * battery_level module: fix invalid indexing, skip batteries with unavailable info (#2180), by lasers
  * vpn_status module: add wireguard support (#2181), by javiertury
* Tue Feb 28 2023 Dawid Adam <nyslay@gmail.com>
- Update to 3.49:
  * do_not_disturb module: use 'makoctl mode' to check current mode. (#2172), by Valdur Kana
  * google_calendar module: add support to configure which google calendar will be used (#2174), by Alex Thomae
* Tue Feb 28 2023 Dawid Adam <nyslay@gmail.com>
- Update to 3.48:
  * IMPORTANT: bluetooth module has been replaced by the bluetooth2 code, please migrate
  * python: drop py 3.6 from CI and bump 3.11 (#2166)
  * battery_level module: allow icon to not use charging_character (#2158), by Kevin Pulo
  * bluetooth module: replaced by bluetooth2 as announced on 2022-10
  * check_tcp module: add IPv6 support (#2167), by Björn Busse
  * clock module: migrate to standard zoneinfo with 3.7, 3.8 support. (#2155), by Valdur Kana
  * events: change the reading timeout to infinity (#2153), by Austin Lund
  * kdeconnector module: Active notifications were always 1. (#2170), by Valdur Kana
  * kdeconnector module: refactor to use dbus signals to update module (#2168), by Valdur Kana
  * kdeconnector module: show cell network type and strength. (#2162) (#2163), by Valdur Kana
  * mpris module: fix error self.parent on Py3status module not found. (#2169), by Valdur Kana
  * timewarrior module: remove dependency on dateutil (#2161), by Rasmus Rendal
  * volume_status module: amixer scontrols uses device and card parameter. (#2152), by Valdur Kana
  * volume_status module: deprecate start_delay parameter
  * volume_status module: smarter initialization logic with retry, remove start_delay setting (#2165), by Joan Bruguera
  * window module: window without title will not produce error on i3msg mode, by Valdur Kana* core: add inhibition timer on misbehaving signals
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.47:
  * INFORMATION: the upcoming bluetooth module has been merged as bluetooth2, users are encouraged to switch
  * core: simpler logic to inhibit out of order signaling
  * formatter: add escape command to escape html
  * new module from scratch: bluetooth2
  * mpris module: different players can use chromium busname, skip cache
  * taskwarrior module: add report parameter
  * volume_status module: autoselect channel on amixer backend
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
-Update to 3.46:
  * INFORMATION: we plan to replace the bluetooth module with a more flexible one in coming releases
  * core: use git package for logging git commit information if available
  * docs: add Alpine Linux installation instructions
  * new audiosink module: switch between pulseaudio sinks from your bar
  * sysdata module: ignore ZFS ARC cache in memory usage
  * volume_status module: add start_delay to address issue
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
-Update to 3.45:
  * official python3.6 support removed
  * mail module: fix pathlib adoption
  * twitch module: migrate to new Twitch API, fix
  * volume_status module: use mapped volume with amixer backend.
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.44
  * IMPORTANT: python3.6 support will be removed on next release
  * core: handle SIGTSTP/SIGCONT better for after sleep freezes
  * formatter: stop escaping html characters on pango markup
  * module_test: add clear_timeout_due
  * udev monitor: implement udev events throttling with warnings
  * google_calendar module: escape html on event summary for pango
  * mpris module: add player_shortname placeholder for displaying player busname
  * xrandr module: fix missing " at the end of documentation line.
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.43
  * core: rework SIGSTP inhibition to support both #2068 and #2107
  * formatter: pango markup should escape all html character
  * py3.safe_format: add information about invalid format
  * py3.safe_format: implement a generic max_width parameter
  * requirements: fix click dependency with black
  * udev monitor: don't trigger actions when i3bar refresh is stopped
  * weather_owm module: dont use onecall for better current day forecast
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.42:
  * core: fix root cause of negative update_due
  * external_script module: add option 'convert_numbers' to preserve number formatting
  * khal_calendar module: add option to limit the number of returned calendar entries
  * mpris module: total rework with bug fixes
  * weather_own module: fix onecall when city is specified
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.41:
  * core: drop and log negative new_update_due which causes high cpu load and endless loop (closses #2085) (#2092), by Valdur Kana
  * core: switch from time.perf_counter to time.monotonic
  * core: timeout due to return something >= 0 instead of None
  * new option py3status.stop_signal to disable i3bar stop/resume
  * arch_updates module: paru exits with a non-zero status if there are no updates
  * battery_level module: fallback to power_now if no current_now
  * events: fix pydevd.debugger first click caused "JSONDecodeError: Expecting value: line 1 column 2 (char 1)".
  * net_iplist module: support parsing iface name with "@" symbol
  * pomodoro module: pyglet and pygame are no longer needed after the merge of
  * scratchpad module: workaround for i3ipc 2.2.1 not finding leaves() in sway
  * sysdata module: add tctl sensor
  * velib_metropole module: drop obsolete module
  * weather_owm module: fix forecast by using new onecall api endpoint
  * window module: i3ipc backend uses incoming event data and relies less on get_tree.focused() data.a
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.40:
  * README: update readthedocs links to new documentation
  * i3 contrib page: update readthedocs links to new documentation
  * i3 contrib page: update to sync with i3.github.io
  * core: inhibit conflicting SIGCONT SIGTSTP that can be received too fast
  * core: fix i3/sway detection
  * formatter: support pango special & character
  * bump mkdocs from 1.2.1 to 1.2.3 in /requirements
  * battery_level module: add configurable status strings
  * do_not_disturb module: handle mako using makoctl
  * vpn_status module: fix changed dbus signal handler signature
  * whoami module: add {hostname} placeholder to output
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.39
  * documentation was refactored to use MkDocs, lots of work has been done
  * add a makefile to ease tasks
  * create and split project, documentation and tests requirements
  * tests: update tox and module tests to match mkdocs md format
  * new sway_idle module: to display the idle state of sway wm
  * clock module: compatible with tzlocal 3.0
  * speedtest module: fix error when clicking too fast
  * weather_owm module: _format_sunrise and _format_sunset as aware datetime
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.38
  * update IRC doc to OFTC
  * arch_updates module: add paru support
  * spotify module: work around play/pause bug in spotifyd
  * weather_owm module: added support for displaying wind speeds in knots
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.37
  * require setuptools: py3status/core.py and tests/test_user_modules.py import pkg_resources
  * help: clarify connection between --debug and --log-file options
  * tox: exit on first error
  * bitcoin_price module: remove module due to unmaintained APIs
  * exchange_rate module: update code to require an api key fix
  * kdeconnector module: add support for version 20.12.3
  * lm_sensors module: replace raw with json output
  * timewarrior module: remove timezone info from end date
  * weather_owm module: avoid customized formats in module_test
  * weather_owm module: remove hardcoded rounded numbers
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.36
  * new zypper_updates module: to watch for OpenSuse updates
  * clock module: switch back to time.time
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.35
  * fix time modules synchronization bug
  * core: fix detection of instances of user provided modules fix
  * docs: fix NixOS instructions to address
  * add github issue templates
  * bluetooth module: add missing requirement
  * sysdata module: rename temp_unit to cpu_temp_unit and drop zone config to support intel, amd, RPi
  * weather_owm module: add wind direction placeholder
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
-Update to 3.34
  * storage: fix Path generation in storage fixes
  * battery_level module: fix converting seconds to H:M:S format
  * google_calendar module: add options to personalize behavior
  * kdeconnector module: fix for battery unavailable
  * lm_sensors module: fix an issue when sensors disconnect and are not detected again
  * net_iplist module: show only non deprecated ipv6 addresses
  * networkmanager module: make format_device less confusing in docstring
  * volume_status module: log available devices only on change
  * volume_status module: run with either pulseaudio or pipewire installed
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.33
  * HOTFIX: this hotfix release fixes py3-cmd
  * IMPORTANT: since we touched a lot of stuff in 3.32, we might have broken stuff.
  * command: fix py3-cmd refresh error
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.32
  * IMPORTANT: a lot of python3 and code normalization happened
  * core: upgrade to python 3.6 syntax using pyupgrade
  * core: modernize python3 code
  * py3status code uses f-strings
  * use list/generator/dict comprehensions where appropriate
  * use pathlib everywhere to manipulate paths and files
  * use shutil.which() instead of external which binary
  * use time.perf_counter to measure short time periods
  * add github project sponsoring
  * argparsers: add missing path on default value
  * argparsers: make sure FILE and PATH options are Path objects
  * battery_level module: fix float formatting with f-strings
  * better usage of timedelta/time modules
  * ci: switch to GitHub Actions CI
  * command: fix binding on PosixPath instead of a bytes-like object
  * core: honor the "colors" general directive thx to @infabo fixes
  * docs: fix building of html docs
  * drop travis-ci
  * fix sys.path manipulation in setup.py as reported by @X-dark
  * i3status module: use datetime.timezone for a custom tz
  * i3status module: add markup support for time,tztime modules,
  * mpd_status module: fixes extra space in the state when there's no artist
  * mpris module: fixes mpris for Chrome, too.
  * remove obsolete numeric relics from Python 2
  * spotify module: fix QA black format* Drop Python 3.5 support,
  * taskwarrior module: replace pytz with datetime.timezone
  * volume_status module: stop spamming logs fixes
  * window module: change i3ipc to required dependency
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.31
  * core: new "on_error" parameter to control module error behavior
  * doc: add CorruptCommit 's configuration examples
  * doc: create a user contributed conf example section thx to
  * update python version compatibility, 3.5 is gone, 3.9 is out
  * parse_config: report missing file command fixes
  * add poweron architecture ppc64le to travis build
  * clock module: handle timezone changes, thx to @sTiKyt fix
  * coin_market module: broken module rewrite fixes
  * diskdata module: ignore df -k errors
  * do_not_disturb module: enhance dunst support using 1.5.0 dunstctl
  * hueshift module: fix initialization incrementing cached value by delta
  * i3status: add support for '%%+' time format
  * mpris module: don't join the artist fields in BrokenDBusMpris
  * spotify module: add spotifyd support
  * sysdata module: increasing meminfo readable lines count to support Raspberry Pi4
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.30:
  * battery_level module: fix filter in /sys thanks to @naclander and @armandg
  * battery_level module: fix logic to skip batteries and charged state detection
  * volume_status module: device parameter can be used as a regex
  * volume_status module: log available devices on default mode
* Mon Oct  3 2022 Dawid Respondek <nyslay@gmail.com>
- Update to 3.29:
  * fix flake8 code linting and black code formatting to pass tests
  * py3.requests: return empty json on remote server problem fix
  * battery_level module: add power consumption placeholder
  * battery_level module: support more battery paths detection
  * core modules: remove deprectated function, fix type annotation support
  * do_not_disturb module: change pause default from False to True
  * google_calendar module: fix imports for newer google-python-client-api versions
  * mpris module: implement broken chromium mpris interface workaround
  * new module prometheus: display prometheus query results on your bar
  * new module watson: to use the watson time-tracking tool
  * sysdata module: add {mem,swap}_free, {mem,swap}_free_unit, {mem,swap}_free_percent
  * sysdata module: try to use default intel/amd sensors first
  * tox CI: force version of black to avoid reformatting failure
  * volume_status module: document commands to print possible devices
* Mon Feb 22 2021 Markéta Machová <mmachova@suse.com>
- Drop broken %%ifpython3 macro
* Wed Apr 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.28:
  * IMPORTANT: drop support for EOL Python 2.6-3.4
  * clock module: add "locale" config parameter to change time representation
  * mpd_status module: use currentsong command if possible
  * networkmanager module: allow using the currently active AP in formats
  * volume_status module: change amixer flag ordering fix
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.27:
  * various minor fixes
* Mon Oct 21 2019 John Vandenberg <jayvdb@gmail.com>
- Recommend i3status, with note that it is optional
- Add configuration.rst to docs
- Update to v3.21
  * New module networkmanager
  * many other fixes, see CHANGELOG
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.20:
  * introduce entry point based discovery of packaged custom modules
  * many other fixes, see CHANGELOG
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use the pytest macro
* Fri May 24 2019 pgajdos@suse.com
- version update to 3.19
  * many changes, see CHANGELOG file
- deleted patches
  - fast-entrypoints.patch (upstreamed)
* Wed Aug 22 2018 tchvatal@suse.com
- Version  update to 3.12:
  * For the list of changes please see CHANGELOG file
- Enable tests
- Add patch fast-entrypoints.patch to fix setup.py
* Thu Mar 22 2018 sleep_walker@opensuse.org
- move license file to %%license
* Wed Mar 21 2018 sleep_walker@opensuse.org
- Update to version 3.7
  for list of changes see CHANGELOG
* Wed Apr 12 2017 toddrme2178@gmail.com
- Update to version 3.5
- Port to singlespec.
* Tue May 17 2016 tcech@suse.com
- let there by py3status!
